@@ -1,7 +1,8 @@
 from .Category import Category
 from .Classification import Classification, ClassificationElement
 from .PropertyDefinition import PropertyDefinition
-from .WorkItem import WorkItemActivity 
+from .WorkItem import WorkItem, WorkItemActivity 
+from .WorkTemplate import WorkTemplate, WorkTemplateActivity
 from .Activity import Activity, Input, ActivityMediaReference
 from .Deviation import Deviation
 from .Media import Media
@@ -18,6 +19,8 @@ __all__ = [
     'WorkItem',
     'Input',
     'WorkItemActivity',
+    'WorkTemplate',
+    'WorkTemplateActivity',
     'Media',
     'MediaReference',
     'ActivityMediaReference'
